Package: av
Type: Package
Title: Working with Audio and Video in R
Version: 0.8.5
Authors@R: person("Jeroen", "Ooms", role = c("aut", "cre"), email = "jeroen@berkeley.edu",
    comment = c(ORCID = "0000-0002-4035-0289"))
Description: Bindings to 'FFmpeg' <http://www.ffmpeg.org/> AV library for working with 
    audio and video in R. Generates high quality video from images or R graphics with 
    custom audio. Also offers high performance tools for reading raw audio, creating
    'spectrograms', and converting between countless audio / video formats. This package 
    interfaces directly to the C API and does not require any command line utilities.
License: MIT + file LICENSE
URL: https://ropensci.r-universe.dev/av, https://docs.ropensci.org/av/
BugReports: https://github.com/ropensci/av/issues
Encoding: UTF-8
RoxygenNote: 7.2.1
SystemRequirements: FFmpeg (>= 3.2); with at least libx264 and lame
        (mp3) drivers. MacOS Homebrew: ffmpeg. Debian/Ubuntu:
        libavfilter-dev. Fedora/CentOS: either ffmpeg-free-devel or
        (via https://rpmfusion.org) ffmpeg-devel.
Depends: R (>= 3.5)
Imports: graphics
Config/pkgdown: seewave, ggplot2, phonTools, signal, tuneR
Suggests: testthat, ps, ggplot2, gapminder
Language: en-US
NeedsCompilation: yes
Packaged: 2023-09-25 17:12:38 UTC; jeroen
Author: Jeroen Ooms [aut, cre] (<https://orcid.org/0000-0002-4035-0289>)
Maintainer: Jeroen Ooms <jeroen@berkeley.edu>
Repository: CRAN
Date/Publication: 2023-09-25 20:40:02 UTC
