Package: av
Type: Package
Title: Working with Audio and Video in R
Version: 0.9.6
Authors@R: 
    person("Jeroen", "Ooms", , "jeroenooms@gmail.com", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-4035-0289"))
Description: Bindings to 'FFmpeg' <http://www.ffmpeg.org/> AV library for working with 
    audio and video in R. Generates high quality video from images or R graphics with 
    custom audio. Also offers high performance tools for reading raw audio, creating
    'spectrograms', and converting between countless audio / video formats. This package 
    interfaces directly to the C API and does not require any command line utilities.
License: MIT + file LICENSE
URL: https://ropensci.r-universe.dev/av, https://docs.ropensci.org/av/
BugReports: https://github.com/ropensci/av/issues
Encoding: UTF-8
RoxygenNote: 7.3.2
SystemRequirements: FFmpeg (>= 3.2); with at least libx264 and lame
        (mp3) drivers. MacOS Homebrew: ffmpeg. Debian/Ubuntu:
        libavfilter-dev. Fedora/RHEL: either ffmpeg-devel from
        https://rpmfusion.org (preferred), or libavfilter-free-devel
        which is a more limited version available on Fedora/EPEL9.
Depends: R (>= 3.5)
Imports: graphics
Config/Needs/website: seewave, ggplot2, phonTools, signal, tuneR
Suggests: curl, testthat, ps, ggplot2, gapminder
Language: en-US
NeedsCompilation: yes
Packaged: 2025-10-19 16:45:30 UTC; jeroen
Author: Jeroen Ooms [aut, cre] (ORCID: <https://orcid.org/0000-0002-4035-0289>)
Maintainer: Jeroen Ooms <jeroenooms@gmail.com>
Repository: CRAN
Date/Publication: 2025-10-20 05:10:40 UTC
