# Generated by roxygen2: do not edit by hand

S3method(plot,av_fft)
export(av_audio_convert)
export(av_capture_graphics)
export(av_decoders)
export(av_demo)
export(av_demuxers)
export(av_encode_video)
export(av_encoders)
export(av_filters)
export(av_log_level)
export(av_media_info)
export(av_muxers)
export(av_spectrogram_video)
export(av_video_convert)
export(av_video_images)
export(av_video_info)
export(bartlett)
export(bhann)
export(bharris)
export(blackman)
export(bnuttall)
export(bohman)
export(cauchy)
export(dolph)
export(flattop)
export(gauss)
export(hamming)
export(hanning)
export(lanczos)
export(nuttall)
export(parzen)
export(read_audio_bin)
export(read_audio_fft)
export(sine)
export(tukey)
export(welch)
export(write_audio_bin)
importFrom(graphics,abline)
importFrom(graphics,image)
importFrom(graphics,legend)
importFrom(graphics,par)
useDynLib(av,R_audio_bin)
useDynLib(av,R_audio_fft)
useDynLib(av,R_convert_audio)
useDynLib(av,R_encode_video)
useDynLib(av,R_generate_window)
useDynLib(av,R_get_open_handles)
useDynLib(av,R_list_codecs)
useDynLib(av,R_list_demuxers)
useDynLib(av,R_list_filters)
useDynLib(av,R_list_muxers)
useDynLib(av,R_log_level)
useDynLib(av,R_video_info)
